@@ -6,7 +6,7 @@ use Alien::Build::Plugin;
 use Carp ();
 
 # ABSTRACT: Probe system and determine library or tool properties using the pkg-config command line interface
-our $VERSION = '1.69'; # VERSION
+our $VERSION = '1.78'; # VERSION
 
 
 has '+pkg_name' => sub {
@@ -188,7 +188,7 @@ Alien::Build::Plugin::PkgConfig::CommandLine - Probe system and determine librar
 
 =head1 VERSION
 
-version 1.69
+version 1.78
 
 =head1 SYNOPSIS
 
@@ -249,7 +249,7 @@ Contributors:
 
 Diab Jerius (DJERIUS)
 
-Roy Storey
+Roy Storey (KIWIROY)
 
 Ilya Pavlov
 
